@@ -24,10 +24,11 @@
 #========================================================================
 
 package Pod::POM;
-
-require 5.004;
+$Pod::POM::VERSION = '0.30';
+require 5.006;
 
 use strict;
+use warnings;
 
 use Pod::POM::Constants qw( :all );
 use Pod::POM::Nodes;
@@ -35,7 +36,6 @@ use Pod::POM::View::Pod;
 
 use parent qw( Exporter );
 
-our $VERSION = '0.29';
 our $DEBUG   = 0 unless defined $DEBUG;
 our $ROOT    = 'Pod::POM::Node::Pod';               # root node class
 our $TEXTSEQ = 'Pod::POM::Node::Sequence';          # text sequence class
@@ -180,7 +180,9 @@ sub parse_text {
         my($encline,$chunk) = splice @encchunks, 0, 2;
         require Encode;
         my($encoding) = $encline =~ /^=encoding\s+(\S+)/;
-        Encode::from_to($chunk, $encoding, "utf8");
+        if ($encoding ne 'utf8' || !Encode::is_utf8($chunk)) {
+	        Encode::from_to($chunk, $encoding, "utf8");
+	    }
         Encode::_utf8_on($chunk);
         # $text .= "xxx$encline";
         $text .= $chunk;
@@ -546,7 +548,7 @@ Pod::POM - POD Object Model
 
     # create custom view
     package My::View;
-    use base qw( Pod::POM::View::HTML );
+    use parent qw( Pod::POM::View::HTML );
 
     sub view_head1 {
 	my ($self, $item) = @_;
@@ -993,7 +995,7 @@ Now the real magic comes into effect.  You can define one view to
 render bold/italic text in one style:
 
     package My::View::Text;
-    use base qw( Pod::POM::View::Text );
+    use parent qw( Pod::POM::View::Text );
 
     sub view_seq_bold {
 	my ($self, $text) = @_;
@@ -1008,7 +1010,7 @@ render bold/italic text in one style:
 And another view to render it in a different style:
 
     package My::View::HTML;
-    use base qw( Pod::POM::View::HTML );
+    use parent qw( Pod::POM::View::HTML );
 
     sub view_seq_bold {
 	my ($self, $text) = @_;
@@ -1602,10 +1604,6 @@ Andy Wardley E<lt>abw@kfs.orgE<gt>
 
 Andrew Ford E<lt>A.Ford@ford-mason.co.ukE<gt> (co-maintainer as of 03/2009)
 
-=head1 VERSION
-
-This is version 0.28 of the Pod::POM module.
-
 =head1 COPYRIGHT
 
 Copyright (C) 2000-2009 Andy Wardley.  All Rights Reserved.
