@@ -7,31 +7,33 @@
 #
 # AUTHOR
 #   Andy Wardley   <abw@kfs.org>
+#   Andrew Ford    <a.ford@ford-mason.co.uk>
 #
 # COPYRIGHT
 #   Copyright (C) 2000, 2001 Andy Wardley.  All Rights Reserved.
+#   Copyright (C) 2009 Andrew Ford.  All Rights Reserved.
 #
 #   This module is free software; you can redistribute it and/or
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: Constants.pm 14 2009-03-13 08:19:40Z ford $
+#   $Id: Constants.pm 89 2013-05-30 07:41:52Z ford $
 #
 #========================================================================
 
 package Pod::POM::Constants;
-
-require 5.004;
+$Pod::POM::Constants::VERSION = '0.30';
+require 5.006;
 
 use strict;
-use vars qw( $VERSION @SEQUENCE @STATUS @EXPORT_OK %EXPORT_TAGS );
-use base qw( Exporter );
+use warnings;
 
-$VERSION   = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
-@SEQUENCE  = qw( CMD LPAREN RPAREN FILE LINE CONTENT );
-@STATUS    = qw( IGNORE REDUCE REJECT );
-@EXPORT_OK = ( @SEQUENCE, @STATUS );
-%EXPORT_TAGS = ( 
+use parent qw( Exporter );
+
+our @SEQUENCE  = qw( CMD LPAREN RPAREN FILE LINE CONTENT );
+our @STATUS    = qw( IGNORE REDUCE REJECT );
+our @EXPORT_OK = ( @SEQUENCE, @STATUS );
+our %EXPORT_TAGS = ( 
     status => [ @STATUS ], 
     seq    => [ @SEQUENCE ],
     all    => [ @STATUS, @SEQUENCE ], 
@@ -52,3 +54,28 @@ use constant REJECT => 2;
 
 
 1;
+
+=head1 NAME
+
+Pod::POM::Constants
+
+=head1 DESCRIPTION
+
+Constants used by Pod::POM.
+
+=head1 AUTHOR
+
+Andy Wardley E<lt>abw@kfs.orgE<gt>
+
+Andrew Ford E<lt>a.ford@ford-mason.co.ukE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2000, 2001 Andy Wardley.  All Rights Reserved.
+
+Copyright (C) 2009 Andrew Ford.  All Rights Reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
