@@ -23,8 +23,10 @@
 #========================================================================
 
 package Pod::POM::Node::Pod;
-
+$Pod::POM::Node::Pod::VERSION = '0.30';
+require 5.006;
 use strict;
+use warnings;
 
 use parent qw( Pod::POM::Node );
 
