@@ -20,15 +20,16 @@
 #========================================================================
 
 package Pod::POM::Test;
-
-require 5.004;
+$Pod::POM::Test::VERSION = '0.30';
+require 5.006;
 
 use strict;
+use warnings;
+
 use Pod::POM;
-use base qw( Exporter );
-use vars qw( $VERSION @EXPORT );
+use parent qw( Exporter );
+use vars qw( @EXPORT );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.1.1.1 $ =~ /(\d+)\.(\d+)/);
 @EXPORT  = qw( ntests ok match assert );
 
 my $ok_count;
