@@ -16,18 +16,19 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: View.pm 14 2009-03-13 08:19:40Z ford $
+#   $Id: View.pm 32 2009-03-17 21:08:25Z ford $
 #
 #========================================================================
 
 package Pod::POM::View;
-
-require 5.004;
+$Pod::POM::View::VERSION = '0.30';
+require 5.006;
 
 use strict;
-use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD $INSTANCE );
+use warnings;
+
+use vars qw( $DEBUG $ERROR $AUTOLOAD $INSTANCE );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0 unless defined $DEBUG;
 
 
@@ -124,6 +125,43 @@ sub AUTOLOAD {
 
 1;
 
+=head1 NAME
 
+Pod::POM::View
 
+=head1 DESCRIPTION
 
+Visitor class for creating a view of all or part of a Pod Object Model.
+
+=head1 METHODS
+
+=over 4
+
+=item C<new>
+
+=item C<print>
+
+=item C<view>
+
+=item C<instance>
+
+=item C<visit>
+
+=item C<leave>
+
+=item C<visiting>
+
+=back
+
+=head1 AUTHOR
+
+Andy Wardley E<lt>abw@kfs.orgE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2000, 2001 Andy Wardley.  All Rights Reserved.
+
+This module is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+=cut
