@@ -15,21 +15,21 @@
 #   modify it under the same terms as Perl itself.
 #
 # REVISION
-#   $Id: Pod.pm 35 2009-03-17 21:11:53Z ford $
+#   $Id: Pod.pm 77 2009-08-20 20:44:14Z ford $
 #
 #========================================================================
 
 package Pod::POM::View::Pod;
-
-require 5.004;
-
+$Pod::POM::View::Pod::VERSION = '0.30';
+require 5.006;
 use strict;
+use warnings;
+
 use Pod::POM::Nodes;
 use Pod::POM::View;
-use base qw( Pod::POM::View );
-use vars qw( $VERSION $DEBUG $ERROR $AUTOLOAD $MARKUP );
+use parent qw( Pod::POM::View );
+use vars qw( $DEBUG $ERROR $AUTOLOAD $MARKUP );
 
-$VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
 $DEBUG   = 0 unless defined $DEBUG;
 
 # create reverse lookup table mapping method name to original sequence
@@ -158,7 +158,9 @@ sub view_begin {
 	. $begin->format() 
 	. "\n\n"
 	. $begin->content->present($self)
-        . "=end\n\n";
+        . "=end "
+	. $begin->format() 
+	. "\n\n";
 }
     
 
